@@ -2,10 +2,9 @@ from .base_file import BaseFile, concat_data
 from .base_folder import BaseFolder, Folder
 from .csv_file import CsvFile
 from .env_file import EnvFile
-from .helpful import BaseHash, read_file_by_module, \
-    concat_absolute_dir_path, absolute_path_dir
+from .helpful import BaseHash, read_file_by_module, concat_absolute_dir_path, absolute_path_dir
 from .json_file import JsonFile
+from .log_file import LogFile
 from .pickle_file import PickleFile
 from .txt_file import TxtFile
 from .yaml_file import YamlFile
-from .log_file import *
