@@ -2,34 +2,61 @@ import importlib.util
 import re
 from hashlib import sha256
 from importlib.machinery import ModuleSpec
+from os.path import splitext
 from pathlib import Path
 from types import ModuleType
 from typing import Optional, Union
 
 
-def sha256sum(path_file: str):
-    """
-    Получить хеш сумму файла
-    @param path_file: Путь к файлу
-    """
-    h = sha256()
-    b = bytearray(128 * 1024)
-    mv = memoryview(b)
-    with open(path_file, 'rb', buffering=0) as f:
-        for n in iter(lambda: f.readinto(mv), 0):
-            h.update(mv[:n])
-    return h.hexdigest()
+class BaseHash:
+
+    @staticmethod
+    def file(path_file: str):
+        """
+        Получить хеш сумму данных в файле, по его пути
+
+        :param path_file: Путь к файлу
+        """
+        h = sha256()
+        b = bytearray(128 * 1024)
+        mv = memoryview(b)
+        with open(path_file, 'rb', buffering=0) as f:
+            for n in iter(lambda: f.readinto(mv), 0):
+                h.update(mv[:n])
+        return h.hexdigest()
+
+    @staticmethod
+    def text(text: str) -> str:
+        """
+        Получить хеш сумму текста
+        """
+        return sha256(text.encode()).hexdigest()
+
+    @staticmethod
+    def check_hash_sum(unknown_hash_sum: str, true_hash_sum: str):
+        """
+        Сравить хеш суммы
+
+        :param unknown_hash_sum: Полученная(неизвестная) хеш сумма
+        :param true_hash_sum: Требуемая хеш сумма
+        """
+        if unknown_hash_sum != true_hash_sum:
+            raise ValueError(f"{unknown_hash_sum} != {true_hash_sum}")
+        return True
 
 
-def read_file_by_module(infile: str) -> ModuleType:
+def read_file_by_module(_path: str) -> ModuleType:
     """
     Импортировать файл как модуль `python`
 
-    :param infile: Путь к `python` файлу
+    :param _path: Путь к `python` файлу
     :return: Модуль `python`
     """
+    # Если не нужно проверять имя расширения
+    if splitext(_path)[1] != ".py":  # Проверяем расширение файла
+        raise ValueError(f"Файл должен иметь расширение .py")
     # указать модуль, который должен быть импортируется относительно пути модуль
-    spec: Optional[ModuleSpec] = importlib.util.spec_from_file_location("my_module", infile)
+    spec: Optional[ModuleSpec] = importlib.util.spec_from_file_location("my_module", _path)
     # создает новый модуль на основе спецификации
     __module: ModuleType = importlib.util.module_from_spec(spec)
     # выполняет модуль в своем собственном пространстве имен,
